@@ -53,7 +53,8 @@ typedef struct GnomeVFSDirectoryHandle GnomeVFSDirectoryHandle;
 typedef enum {
 	GNOME_VFS_DIRECTORY_VISIT_DEFAULT = 0,
 	GNOME_VFS_DIRECTORY_VISIT_SAMEFS = 1 << 0,
-	GNOME_VFS_DIRECTORY_VISIT_LOOPCHECK = 1 << 1
+	GNOME_VFS_DIRECTORY_VISIT_LOOPCHECK = 1 << 1,
+	GNOME_VFS_DIRECTORY_VISIT_IGNORE_RECURSE_ERROR = 1 << 2
 } GnomeVFSDirectoryVisitOptions;
 
 /**
